package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````OAT```````!``````````#BA````
M`````````$``.``(`$``&0`8``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````9`````````!D``````````0`````````!````
M!0```````````````````````````````````&R3````````;),`````````
M`"````````$````&````V)L```````#8FR```````-B;(```````B`0`````
M```P%0``````````(````````@````8````HG````````"B<(```````*)P@
M``````"@`0```````*`!````````"`````````!0Y71D!````%2.````````
M5(X```````!4C@```````,P`````````S``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```#8FP```````-B;(```````V)L@```````H!```````
M`"@$`````````0`````````O;&EB+VQD+6UU<VPM>#@V7S8T+G-O+C$`````
M`````!$```!$````!`````@````@#```!4`$@B@`4`"0A@"`@B$`($D"!`FX
M@AA)N@0&"D0```!%````20```$T```!.````5````%4```!7`````````%L`
M````````7````%X```!?````8```````````````H^D9!&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'PA_^0.V7%8'/JA;&#"Y3\LL@&+;_+;TQWB1\8!
MN^.2?%7#/-+$N9Q`9Z_,9CCRBQS$B060B`=PTT-%U>PS8MOM5J2;EJ?=HVM_
MJ9R;X:<""@J*$%>CX/M)``````````````````````````````````````P`
M```2`````````````````````````,X!```2````````````````````````
M`'`!```2`````````````````````````!L````2````````````````````
M`````*T!```2`````````````````````````",````2````````````````
M`````````"H````2``````````````````````````$"```2````````````
M`````````````+D!```2`````````````````````````#,````@````````
M`````````````````$L````2`````````````````````````%$````2````
M`````````````````````%@````2`````````````````````````!`#```2
M``````````````````````````$#```2`````````````````````````(8"
M```2`````````````````````````%\````2````````````````````````
M`"<"```2`````````````````````````&8````2````````````````````
M`````+L"```2`````````````````````````&T````2````````````````
M`````````'4````@`````````````````````````(D````2````````````
M`````````````*0"```2`````````````````````````)$````2````````
M`````````````````)<````2`````````````````````````*`````@````
M`````````````````````/H"```2`````````````````````````+P````2
M`````````````````````````,$````2`````````````````````````,("
M```2`````````````````````````%0"```2````````````````````````
M`"`#```2`````````````````````````$8"```2````````````````````
M`````(8#```2`````````````````````````'@"```2````````````````
M`````````#8#```2`````````````````````````,@````2````````````
M`````````````"X#```2`````````````````````````'X!```2````````
M`````````````````-$````B`````````````````````````.`````@````
M`````````````````````/8````2`````````````````````````/("```2
M`````````````````````````&0"```2`````````````````````````/L`
M```2``````````````````````````$!```@````````````````````````
M`*\"```2`````````````````````````!L!```2````````````````````
M`````)X!```2`````````````````````````"`!```2````````````````
M`````````)0"```2`````````````````````````(T!```2````````````
M`````````````"8!```2`````````````````````````#<!```2````````
M`````````````````"("```2`````````````````````````)(````2````
M`````````````````````#,"```2`````````````````````````&T"```2
M`````````````````````````"<#```2`````````````````````````#T!
M```2`````````````````````````!@#```2````````````````````````
M`%$!```2`````````````````````````!T"```2````````````````````
M`````-P!```2`````````````````````````%@!```2````````````````
M`````````&D!```2`````````````````````````$@#```A`!8`:*`@````
M```(`````````$,#```2``H`Z!L```````#6`0```````.X!```2``L`)$\`
M```````!`````````,@#```2``H`ND$```````"I"0```````#X$```2``H`
MKDX```````!1`````````*4#```2``H`HSP````````%`````````-<#```2
M``<`$!@````````!`````````.L#```2``H`8TL```````!+`P```````#$$
M```2``H`J#P```````"T`0```````%H#```0`!8`8*`@````````````````
M`+8#```2``H`)$$```````"6`````````-4#```2``H`-3L````````M````
M`````-T#```2``H`O4````````!(`````````,T"```1`!(`$)P@```````3
M``````````L$```2``H`7#X````````;`````````&8#```0`!8`"+$@````
M`````````````&L#```2``H`U!T````````H`````````$D#```1`!8`:*`@
M```````(`````````!@$```2``H`=SX```````"B`````````!0````1`!(`
M`)P@```````(`````````$H#```A`!8`:*`@```````(``````````$$```1
M`!4`6*`@```````(`````````%,#```0`!4`8*`@`````````````````%\#
M```0``H`OAT``````````````````!("```1`!8`<*`@```````$````````
M`$L#```A`!8`:*`@```````(`````````'0#```2``H`!4$````````?````
M`````(\#```2``H`J#L```````#[`````````/0!```1`!8`8*`@```````!
M`````````"0$```2``H`&3\```````"D`0````````!L:6)P97)L+G-O`&]P
M96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I
M<W1E<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N
M;&EN:P!M96UM;W9E`%]*=E]296=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A
M=`!C;&]S961I<@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S
M=')S='(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M
M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R
M96%D`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S
M<&5C:69I8P!M96UC<'D`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E
M<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD
M=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R
M;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C
M=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E
M<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI
M8F,N;75S;"UX.#9?-C0N<V\N,0!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T
M9F]R:P!R96%D9&ER`'-P<FEN=&8`<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?
M;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T
M`%]E;F0`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!8
M4U]);G1E<FYA;'-?4$%27T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P
M87)?9&ER;F%M90!P87)?:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A
M;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%``"@(```````"```
M````````H"```````""@(```````"``````````24````````"B@(```````
M"``````````+4````````#"@(```````"`````````!.40```````#B@(```
M````"``````````H4````````$"@(```````"`````````!640```````%B@
M(```````"`````````#K40```````+"?(```````!@````H`````````````
M`+B?(```````!@```!8``````````````,"?(```````!@```!L`````````
M`````,B?(```````!@```"D``````````````-"?(```````!@```"H`````
M`````````-B?(```````!@```"\``````````````."?(```````!@```#0`
M`````````````.B?(```````!@```#4``````````````/"?(```````!@``
M`#H```````````````"<(```````!0```%<``````````````!"<(```````
M!0```%$``````````````&"@(```````!0```&```````````````&B@(```
M````!0```%4``````````````'"@(```````!0```%P``````````````."=
M(```````!P````$``````````````.B=(```````!P````(`````````````
M`/"=(```````!P````,``````````````/B=(```````!P````0`````````
M``````">(```````!P````4```````````````B>(```````!P````8`````
M`````````!">(```````!P````<``````````````!B>(```````!P````@`
M`````````````"">(```````!P````D``````````````"B>(```````!P``
M``L``````````````#">(```````!P````P``````````````#B>(```````
M!P````T``````````````$">(```````!P````X``````````````$B>(```
M````!P````\``````````````%">(```````!P```!```````````````%B>
M(```````!P```!$``````````````&">(```````!P```!(`````````````
M`&B>(```````!P```!,``````````````'">(```````!P```!0`````````
M`````'B>(```````!P```!4``````````````(">(```````!P```!<`````
M`````````(B>(```````!P```!@``````````````)">(```````!P```!D`
M`````````````)B>(```````!P```!H``````````````*">(```````!P``
M`!P``````````````*B>(```````!P```!T``````````````+">(```````
M!P```!X``````````````+B>(```````!P```!\``````````````,">(```
M````!P```"```````````````,B>(```````!P```"$``````````````-">
M(```````!P```"(``````````````-B>(```````!P```",`````````````
M`.">(```````!P```"0``````````````.B>(```````!P```"4`````````
M`````/">(```````!P```"8``````````````/B>(```````!P```"<`````
M``````````"?(```````!P```"@```````````````B?(```````!P```"L`
M`````````````!"?(```````!P```"P``````````````!B?(```````!P``
M`"T``````````````""?(```````!P```"X``````````````"B?(```````
M!P```#```````````````#"?(```````!P```#$``````````````#B?(```
M````!P```#(``````````````$"?(```````!P```#,``````````````$B?
M(```````!P```#8``````````````%"?(```````!P```#<`````````````
M`%B?(```````!P```#@``````````````&"?(```````!P```#D`````````
M`````&B?(```````!P```#L``````````````'"?(```````!P```#P`````
M`````````'B?(```````!P```#T``````````````("?(```````!P```#X`
M`````````````(B?(```````!P```#\``````````````)"?(```````!P``
M`$```````````````)B?(```````!P```$$``````````````*"?(```````
M!P```$(``````````````*B?(```````!P```$,``````````````%#HU08`
M`.CD-@``6,,```#_-:J%(`#_):R%(``/'T``_R6JA2``:`````#IX/____\E
MHH4@`&@!````Z=#_____)9J%(`!H`@```.G`_____R62A2``:`,```#IL/__
M__\EBH4@`&@$````Z:#_____)8*%(`!H!0```.F0_____R5ZA2``:`8```#I
M@/____\E<H4@`&@'````Z7#_____)6J%(`!H"````.E@_____R5BA2``:`D`
M``#I4/____\E6H4@`&@*````Z4#_____)5*%(`!H"P```.DP_____R5*A2``
M:`P```#I(/____\E0H4@`&@-````Z1#_____)3J%(`!H#@```.D`_____R4R
MA2``:`\```#I\/[___\E*H4@`&@0````Z>#^____)2*%(`!H$0```.G0_O__
M_R4:A2``:!(```#IP/[___\E$H4@`&@3````Z;#^____)0J%(`!H%````.F@
M_O___R4"A2``:!4```#ID/[___\E^H0@`&@6````Z8#^____)?*$(`!H%P``
M`.EP_O___R7JA"``:!@```#I8/[___\EXH0@`&@9````Z5#^____)=J$(`!H
M&@```.E`_O___R72A"``:!L```#I,/[___\ERH0@`&@<````Z2#^____)<*$
M(`!H'0```.D0_O___R6ZA"``:!X```#I`/[___\ELH0@`&@?````Z?#]____
M):J$(`!H(````.G@_?___R6BA"``:"$```#IT/W___\EFH0@`&@B````Z<#]
M____)9*$(`!H(P```.FP_?___R6*A"``:"0```#IH/W___\E@H0@`&@E````
MZ9#]____)7J$(`!H)@```.F`_?___R5RA"``:"<```#I</W___\E:H0@`&@H
M````Z6#]____)6*$(`!H*0```.E0_?___R5:A"``:"H```#I0/W___\E4H0@
M`&@K````Z3#]____)4J$(`!H+````.D@_?___R5"A"``:"T```#I$/W___\E
M.H0@`&@N````Z0#]____)3*$(`!H+P```.GP_/___R4JA"``:#````#IX/S_
M__\E(H0@`&@Q````Z=#\____)1J$(`!H,@```.G`_/___R42A"``:#,```#I
ML/S___\E"H0@`&@T````Z:#\____)0*$(`!H-0```.F0_/___R7Z@R``:#8`
M``#I@/S___\E\H,@`&@W````Z7#\____)>J#(`!H.````.E@_/___R7B@R``
M:#D```#I4/S___\EVH,@`&:0_R7J@R``9I#_)>J#(`!FD%-(@^P@B7PD'$B)
M="002(U\)!Q(B50D"$B-="002(U4)`CH8?[__TB+-=J#(`!(BSW+@R``2(GR
MZ-O\__^`/32$(```=37HK?W__TB%P$B)!<.4(`!U"K\!````Z#?^__](B<?H
MC_[__XL]&80@`.@$____QH#1"````(L]!X0@`.CR_O__@(BJ!````HL]]8,@
M`.C@_O__@(BJ!````8M$)!R->`5(N/________\?2&/_2#G'=A5(C35I?R``
M2(T]R3(``#'`Z/O[__](P><#2(T=)34``.C[_?__2(M\)!!(B047E"``,<G'
M!1.4(``$````2(L72(E8"$B-'?TT``!(B5@82(D02(L57X,@`$B)4!"+5"0<
M2/_!.<I^$4R+!,^-<01(8_9,B43P^.OHC4H$2(L]W9,@`$B--3@>``"#P@-%
M,<!(8\E(QT3(^`````!(B<'H//S__X7`B<-U#DB+/:^3(`#H2OW__XG#2(L]
MH9,@`.C,_/__2(T]6C(``#'`Z)<9``!(A<!U+DB#/7F3(```=1-(C3WR,0``
MZ'P9``!(B05DDR``2(L]79,@`$B%_W0%Z`DQ``!(BSU4DR``Z-_]___HFOK_
M_TB#Q"")V%O#2#'M2(GG2(TU77X@`$B#Y/#H`````$B#[`A(C5<(2(LW3(T%
M/C$``$B-#2/Z__]%,<E(C3WQ_?__Z$3\__](C3U=@B``2(T%78(@`%5(*?A(
MB>5(@_@.=@](BP6B@2``2(7`=`-=_^!=PTB-/3&"(`!(C34J@B``N0(```!5
M2"G^2,'^`TB)Y4B)\$B92/?Y2(7`=!)(B<9(BP5[@2``2(7`=`-=_^!=PX`]
M$H(@``!U>DB#/5"!(```54B)Y4%44W0,2(L]>($@`.A+_?__2(T%5'T@`$B-
M'55](`!(*<-)B<1(P?L#2/_+2(L%V8$@`$@YPW802/_`2(D%RH$@`$'_%,3K
MY.@S____2(,]WX`@``!T#$B-/9YP``#H\?S__UM!7%W&!9:!(``!PTB#/=V`
M(```54B)Y7032(TUH($@`$B-/7%P``#HU/S__TB-/>5\(`!(@S\`=`Y(BP68
M@"``2(7`=`+_T%WI^_[__T%7059,C4\X055!5#'V55-(@>R8`@``9$B+!"4H
M````2(F$)(@"```QP$B-3"0(08L$,4V+!#$/R$R)PHG`2,'J($B)!'%,B<!)
MP>@X2,'H*"4`_P``3`G`28G02,'B"$G!X!B!X@``_P!%B<!,"<!("=!(B41Q
M"$B#Q@A(@_Y`=:U,C5EH3(U10$R-21!,C8&`````,=))BP0323,$$DDS!!%(
M,P012(TT`$C!Z!\)\$F)!!!(@\((2('Z``(``'753(L/2(M?($R+1PA,BU<0
M3(M?&$B+3"003(G.3(G(38G/2,'H&TC!Y@5-B<1("<9(BT0D"$R)PHGV2,'J
M`DG!Y!Y)"=1,B=))C8P+F7F"6DB-A`.9>8):18GD2<'G'DPQXD@!\$R)UDPA
MRDPQWDPQTDPAQD@!T4PQWD@!QHGP2(G"2(G%2,'M&TC!X@5(">J)TD@!RDR)
MR4C!Z0)!B=9)"<](B<%,B?5%B?](]]%(P>T;3"'A3"'^2`G.2(M,)!A)C8P*
MF7F"6D@!SDR)\4C!X05(">E(B<5(P>@"2,'E'HG)2`'Q2`GHB<5,B?!!B<U(
M]]!((>I,B>Y,(?A(P>X;2`G"2(M$)"!)C80$F7F"6D@!PDR)Z$C!X`5("?!,
MB>Z)P$CWUD@!T$R)\DG![@)(P>(>2"'N08G$20G62(M4)"A%B?9,(?%("?%)
MC;07F7F"6DR)XDC!ZAM(`?%,B>9(P>8%2`G63(GJ2<'M`DC!XAZ)]DD)U4R)
MXD@!SD6)[4CWTD&)]TPA\DPAZ$R)^4@)T$B+5"0P2,'I&TB-E!69>8):2`'0
M3(GZ2,'B!4@)RDR)^8G22/?12`'"3(G@2,'@'DG![`),(>E)"<1(BT0D.(G5
M18GD3"'F2`G.28V,!IEY@EI(B>A(P>@;2`'.2(GI2,'A!4@)P4R)^$G![P)(
MP>`>B<E)"<=(B>A(`?%%B?](]]!!B<Y,(>!,(?I,B?9("<)(BT0D0$C![AM)
MC80%F7F"6D@!PDR)\$C!X`5("?!,B?:)P$CWUD@!T$B)ZDC![0)(P>(>3"'^
M08G%2`G52(M4)$B)[4@AZ4@)\4F-M!29>8):3(GJ2,'J&T@!\4R)[DC!Y@5(
M"=9,B?*)]D@!SDC!XAY)P>X"20G63(GJ08GT18GV2/?23(GA2"'J3"'P2,'I
M&T@)T$B+5"1028V4%YEY@EI(`=!,B>)(P>(%2`G*3(GAB=)(]]%(`<),B>A)
MP>T"2,'@'DPA\4&)UTD)Q4B+1"1818GM3"'N2`G.2(V,!9EY@EI,B?A(P>@;
M2`'.3(GY2,'A!4@)P4R)X$G![`)(P>`>B<E)"<1,B?A(`?%%B>1(]]")S4PA
MZ$PAXDB)[D@)PDB+1"1@2,'N&TF-A`:9>8):2`'"2(GH2,'@!4@)\$B)[HG`
M2/?62`'03(GZ2<'O`DC!XAY,(>9!B<9)"==(BU0D:$6)_TPA^4@)\4F-M!69
M>8):3(GR2,'J&T@!\4R)]DC!Y@5("=9(B>I(P>T"2,'B'HGV2`G53(GR2`'.
MB>U(]])!B?5,(?I((>A,B>E("=!(BU0D<$C!Z1M)C904F7F"6D@!T$R)ZDC!
MX@5("<I,B>F)TDCWT4@!PDR)\$G![@)(P>`>2"'I08G420G&2(M$)'A%B?9,
M(?9("<Y)C8P'F7F"6DR)X$C!Z!M(`<Y,B>%(P>$%2`G!3(GH2<'M`DC!X!Z)
MR4D)Q4R)X$@!\46)[4CWT$&)STPA\$PAZDR)_D@)PDB+A"2`````2,'N&TB-
MA`69>8):2`'"3(GX2,'@!4@)\$R)_HG`2/?62`'03(GB2<'L`DC!XAY,(>Z)
MQ4D)U$B+E"2(````18GD3"'A2`GQ28VT%IEY@EI(B>I-B?Y(P>H;2<'O`D@!
M\4B)[DG!YAY(P>8%30GW2`G62(GJ18G^2/?23"'PB?9,(>)(`<Y)B>]("=!(
MBY0DD````(GQ28V4%9EY@EI)B<U(`=!(B<I(P>(%2<'M&TG!YQY,">I(P>T"
M3`G]B=)!B>](`<)(B<U(BX0DF````$CWU4PA_DPA]4&)U4@)[DF-K`29>8):
M3(GH2,'H&T@![DR)[4C!Y05("<5(B<A(P>D"2,'@'HGM2`G!3(GH2`'U2/?0
MB<Y!B>Q,(?A((?)("<)(BX0DH````$F-A`:9>8):38GF2<'N&T@!PDR)X$C!
MX`5,"?")P$@!T$R)ZDG![0)(P>(>08G&20G52(N4)*@```!,,>DQS4F-E!>A
MZ]EN2(U,%0!,B?),B?5(P>T;2,'B!4@)ZHG22`'*3(GA2<'L`DC!X1Z)U4P)
MX4V)[$6)[4DQS$P#K"2X````1#'@3(ND)+````!*C;0FH>O9;DF)[$G![!M(
M`?!(B>Y(P>8%3`GF38GT2<'N`DG!Y!Z)]DT)]$F)SD@!\$TQYHG&B<E$,?))
MB?9(`XPDP````$V-K!6AZ]EN2(GR2<'N&TC!X@5,"?*)TDV-=!4`2(GJ2,'M
M`DC!XAY(">I,B>5%B?5(,=5%B>0QZ$B-K`&AZ]EN3(GH3(GI2,'I&TC!X`5(
M"<B)P$B-3`4`2(GU2,'N`DC!Y1Y("?5,`Z0DR````$B)UD@Q[HG(B=)!,?9(
MB<9(`Y0DT````$C!Y@5/C:0TH>O9;DF)QDG![AM,"?:)]DV--#1,B>Y)P>T"
M2,'F'DP)[DF)[46)]$DQ]8GM2`.L)-@```!$,>E-B>5(C8P*H>O9;DR)XDG!
M[1M(P>(%3`GJB=)(`<I(B<%(P>@"2,'A'D&)U4@)P4B)\(GV2#'(2`.T).``
M``!!,<9,B>A.C;0UH>O9;DR)[4C!X`5(P>T;2`GHB<!)C2P&3(G@2<'L`DC!
MX!Y,">!)B<Q!B>Y),<2)R40QXDR-I!:AZ]EN3(GR3(GV2,'B!4C![AM(`XPD
MZ````$@)\HG228TT%$R)ZDG![0)(P>(>3`GJ28G%08GT23'5B<!(`X0D\```
M`$0Q[4V)Y4B-K"FAZ]EN3(GA2<'M&TC!X05,">F)R4@!Z4R)]4G![@)(P>4>
M08G-3`GU28G6B=)),>Y(`Y0D^````$0Q]DV)[DB-M#"AZ]EN3(GH2<'N&TC!
MX`5,"?")P$@!\$R)YDG![`)(P>8>08G&3`GF28GLB>U),?1$,>%-B?1(C8P*
MH>O9;DR)\DG![!M(P>(%3`GBB=)(`<I,B>E(`ZPD``$``$G![0)(P>$>08G4
M3`GI28GUB?9),<U(`[0D"`$``$0QZ$R-K`6AZ]EN3(G@3(GE2,'M&TC!X`5(
M">B)P$F-;`4`3(GP2<'N`DC!X!Y,"?!)B<Y!B>U),<:)R4@#C"00`0``1#'R
M3(VT%J'KV6Y,B>I,B>Y(P>X;2,'B!4@)\HG228TT%DR)XDG![`)(P>(>3`GB
M28G$08GV23'4B<!$,>5-B?1(C:PIH>O9;DR)\4G![!M(P>$%3`GAB<E(`>E,
MB>U)P>T"2,'E'D&)S$P)[4@#A"08`0``28G523'MB=)(`Y0D(`$``$0Q[DV)
MY4G![1M(C;0PH>O9;DR)X$C!X`5,">B)P$@!\$R)]DG![@)(P>8>08G%3`GV
M28GNB>U),?9(`ZPD*`$``$0Q\4V)[DB-C`JAZ]EN3(GJ2<'N&TC!X@5,"?*)
MTD@!RDR)X4G![`)(P>$>08G63`GA28GTB?9),<Q(`[0D,`$``$V)]T0QX$R-
MI`6AZ]EN3(GP3(GU2,'M&TC!X`5(">B)P$F-+`1,B>A)P>T"2,'@'DP)Z$F)
MS4&)[$DQQ8G)1#'J38GE2(VT%J'KV6Y,B>)(P>(%2<'M&T@#C"0X`0``3`GJ
M2<'N`DG!YQZ)TDT)]TV)YDR-+!9(B<9)P>P"3#'^2<'F'HG`1(GJ,?5(`X0D
M0`$``$B-M"FAZ]EN2(G12(G52,'M&TC!X05-">9(">E,B?U%B?],,?6)R4$Q
M[4@!\8G.3HVD**'KV6Y)B=5(B?!(P>H"2(GU2<'E'DC![1M(P>`%20G53(GR
M2`GH3`GJB<!((=%,B?))C2P$3"'JN-R\&X]%B?8)T4B)PD@#E"1(`0``08GL
M3`'Z38GG2`'13(GB2,'B!4G![QM,"?J)TD@!RDB)\4C![@)(P>$>08G72`GQ
M3(GN2`G.2"'U3(GN18GM2"'."?5(B<9(`[0D4`$``$D!]DR)_DD![DR)_4C!
MY@5(P>T;2`GNB?9)C2PV3(GF2<'L`DC!YAY,">9)B<Q!B>Y)"?1,(>))B<R)
MR4DA]$0)XDF)Q$P#I"18`0``30'L38GU3`'B38GT2<'E!4G![!M-">5%B>U.
MC20J3(GZ2<'O`DC!XAY,"?I)B?=%B>5)"==,(?U)B?>)]DDAUT0)_4F)QTP#
MO"1@`0``20'/3(GI3`']38GO2,'A!4G![QM,"?F)R4R-?`T`3(GQ2<'N`DC!
MX1Y,"?%)B=9$B?U)"<Y-(?1)B=:)TDDASD4)]$F)QDP#M"1H`0``20'V2(GN
M30'T28GN2,'F!4G![AM,"?:)]DV--#1-B>Q)P>T"2<'D'DT)[$F)S42)]DT)
MY4TA[TF)S8G)32'E10GO28G%3`.L)'`!``!)`=5(B?)-`>])B?5(P>(%2<'M
M&TP)ZHG238TL%TB)ZDC![0)(P>(>2`G53(GB18GO2`GJ22'63(GB18GD2"'J
M00G62(G"2`.4)'@!``!(`=%,B?I,`?%-B?Y(P>(%2<'N&TP)\HG23(TT$4B)
M\4C![@)(P>$>2`G.2(GI1(GR2`GQ22'-2(GIB>U((?%!"<U(B<%(`XPD@`$`
M`$D!S$B)T4T![$F)U4C!X05)P>T;3`GIB<E-C2P,3(GY2,'A'DG![P),"?E)
MB?=%B>Q)"<]-(?Y)B?>)]DDAST4)_DF)QTP#O"2(`0``20'O3(GE30'^38GG
M2,'E!4G![QM,"?V)[4V-/"Y(B=5(P>H"2,'E'D@)ZDB)S46)_D@)U4DA[4B)
MS8G)2"'500GM2(G%2`.L))`!``!(`>Y,B?5,`>Y-B?5(P>4%2<'M&TP)[8GM
M3(TL+DR)YDG![`)(P>8>20GT2(G61(GM3`GF22'W2(G6B=),(>9!"?=(B<9(
M`[0DF`$``$@!\4B)[DP!^4F)[TC!Y@5)P>\;3`G^B?9,C3PQ3(GV2<'N`DC!
MYAY,"?9-B>9$B?E)"?9-(?5-B>9%B>1)(?9%"?5)B<9,`[0DH`$``$D!UDB)
MRDT!]4F)SDC!X@5)P>X;3`GRB=)-C705`$B)ZDC![0)(P>(>2`G52(GR18GU
M2`GJ22'72(GRB?9((>I!"==(B<)(`Y0DJ`$``$D!U$R)ZDT!_$V)[TC!X@5)
MP>\;3`GZB=)-C3P428G,2<'D'DC!Z0),">%)B>Q$B?I)"<Q-(>9)B>R)[4DA
MS$4)YDF)Q$P#I"2P`0``3`'F28G43`'V28G62<'D!4G![AM-"?1%B>1.C30F
M3(GN2<'M`DC!YAY)"?5(B<Y%B?1,">Y)(?=(B<Z)R4PA[D$)]TB)QD@#M"2X
M`0``2`'U3(GF3`']38GG2,'F!4G![QM,"?Z)]DR-?#4`2(G62,'J`DC!YAY(
M"=9,B>I$B?U("?))(=9,B>I%B>U((?)!"=9(B<)(`Y0DP`$``$@!RDB)Z4D!
MUDB)ZDC!X05(P>H;2`G1B<E)C10.3(GA2<'L`DC!X1Y)"<Q(B?%!B=9,">%)
M(<](B?&)]DPAX4$)STB)P4@#C"3(`0``20'-3(GQ30']38GW2,'A!4G![QM,
M"?F)R4V-?`T`28GM2,'M`DG!Y1Y,">U-B>5$B?E)">U,(>I-B>5%B>1)(>U$
M">I)B<5,`ZPDT`$``$P![DF)S4@!UDB)RDG!Y05(P>H;20G518GM2HT4+DR)
M]DG![@)(P>8>20GV2(GN08G53`GV22'W2(GN3"'V00GW2(G&2`.T)-@!``!(
M`X0DX`$``$D!]$R)[DT!_$V)[TC!Y@5)P>\;3`G^B?9-C3PT2(G.2,'I`DC!
MYAY("<Y,B?%%B?Q("?%((<I,B?%%B?9((?$)RHGI2`'!3(G@2`'*3(GA2,'H
M&TC!X05("<%,B>A)P>T"B<E(P>`>2`'1NM;!8LI,">A)B=5,`ZPDZ`$``(G-
M30'N28GUB?9),<5%,>])B>U-`?=)B>Y)P>4%2<'N&TT)]4V)YDG![`))P>8>
M18GM30GF28G43`.D)/`!``!-`?U%B>],`>9)B<2)P$TQ]$0QX4V)_$@!\4R)
M_DG![!M(P>8%3`GF28GL2,'M`DG!Y!Z)]DD)[$B)U4@#K"3X`0``2`'QB<Y(
M`>A,B?5%B?9,,>5!,>U(B?5)`<5(B?!(P>4%2,'H&T@)Q8GM3`'M38G]2<'E
M'DG![P*)Z$T)_4F)UTP#O"0``@``30'^38GG18GD33'O1#'Y28G'3`'Q28G&
M2<'O&TG!Y@5-"?Y)B?=(P>X"2<'G'D6)]DD)]TB)UD@#M"0(`@``20'.1(GQ
M20'T3(GN18GM3#'^,?5(B<Y,`>5)B<Q(P>8%2<'L&TP)YHGV2`'N2(G%2,'H
M`DC!Y1Y!B?1("<5(B=!(`X0D$`(``$D!Q4R)^$6)_T@QZ$$QQDR)X$T![DV)
MY4C!X`5)P>T;3`GHB<!,`?!)B<Y(P>D"2<'F'D&)Q4P)\4F)UDP#M"08`@``
M30'W28GNB>U),<Y$,?9-B>Y,`?Y-B>])P>X;2<'G!4T)]T6)_TD!]TR)YDG!
M[`)(P>8>18G^20GT2(G62`.T)"`"``!(`?5(B<Z)R4PQYC'P3(GV2`'H3(GU
M2,'N&TC!Y05("?5,B>Y)P>T"2,'F'HGM3`GN28G53`.L)"@"``!(`<6)Z$P!
MZ4V)Y46)Y$DQ]44Q[TF)Q4D!STB)P4G!Y05(P>D;20G-18GM30']38GW2<'N
M`DG!YQY$B>E-"?Y)B==,`[PD,`(``$T!_$F)]XGV33'W1#']28G/3`'E28G,
M2<'O&TG!Y`5-"?Q%B>1)`>Q(B<5(P>@"2,'E'D6)YT@)Z$B)U4@#K"0X`@``
M2`'N3(GU18GV2#'%03'M3(G]20'U3(G^2,'M&TC!Y@5(">Y(B<V)]DP![DC!
MY1Y(P>D"2`G-2(G12`.,)$`"``!!B?5)`<Y(B<&)P$@QZ4$QS$R)Z4T!]$V)
M[DC!X05)P>X;3`GQB<E,`>%-B?Q)P>\"2<'D'D&)SDT)YTF)U$P#I"1(`@``
M3`'@28GLB>U-,?Q$,>9-B?1(`<9,B?!)P>P;2,'@!4P)X(G`2`'P3(GN2<'M
M`DC!YAY!B<1)"?5(B=9(`[0D4`(``$@!]4R)_D6)_TPQ[C'Q3(GF2`'I3(GE
M2,'E!4C![AM("?6)[4@!S4R)\4G![@)(P>$>B>Y)"<Y(B=%(`XPD6`(``$D!
MSTR)Z46)[4PQ\3'(2(GQ3`'X28GW2,'I&TG!YP5)"<],B>%)P>P"2,'A'D6)
M_TP)X4F)U$P#I"1@`@``20''1(GX30'E38GT18GV23',1#'E28G$3`'M28G%
M2<'D!4G![1M-">Q)B?5(P>X"2<'E'D6)Y$D)]4B)UD@#M"1H`@``20'L1(GE
M20'V2(G.B<E,,>Y!,?=(B>Y-`?=)B>Y(P>8%2<'N&TP)]DF)QDC!Z`))P>8>
MB?9)"<9(B=!(`X0D<`(``$P!_D&)]T@!P4R)Z$6)[4PQ\$$QQ$R)^$D!S$R)
M^4C!Z!M(P>$%2`G!B<E,`>%)B>Q(P>T"2<'D'HG(3`GE28G43`.D)'@"``!-
M`>5-B?1),>Q$,>9)B<1)`?5(B<9)P>P;2,'F!4P)YDF)Q$$!]4R)_DC!YAY(
M`Y0D@`(``$C!Z`))P>0>2<'O`D4!Z$D)Q$2)\$P)_D4!XD$!\P'K2`'"2(GH
M3(E'"$@Q\$R)5Q!,B5\8,<%(B5\@2(T$"DR)ZDR)Z4C!X@5(P>D;2`G*`=!!
M`<%(BX0DB`(``&1(,P0E*````$R)#W0%Z$+E__](@<28`@``6UU!7$%=05Y!
M7\-!5T%6055!5%53,>U(@^P(2(7_=&5,BS7,:2``2(GZ387V=%:*`H3`=`D\
M/70%2/_"Z_$I^DF)]TF)_4V)]$ACVDF++"1(A>UT,$B)VDR)[DB)[^B8XO__
MA<!U&(!\'0`]=1%-*?1(C6P=`4G!_`-%B2?K!DF#Q`CKQUI(B>A;74%<05U!
M7D%?PTB#[!AD2(L$)2@```!(B40D"#'`2(UT)`3H6?___TB+5"0(9$@S%"4H
M````=`7H=.3__TB#Q!C#55-(B?M(@^P89$B+!"4H````2(E$)`@QP$B-;"0$
M,<!(B>Y(B=_H%/___TB%P'0B2&-4)`1(BP7K:"``2(T$T$B+4`A(A=)(B1!T
MTDB#P`CK[DB+1"0(9$@S!"4H````=`7H".3__TB#Q!A;7<-!5D%505152(G]
M4TB)\TB#[!!D2(L$)2@```!(B40D"#'`,<"`/CU(C70D!`^4P$F#SO]%,>U(
M`<-,B?%$B.A(B=_RKDB)[TCWT4Z-)#'H?O[__TB%P'0V2(G'2(G"3(GQ1(CH
M\JY)B<U)]]5-`?5-.>P/AZT````QP(H,`X@,`DC_P(3)=?,QP.D4`0``3(LU
M)&@@`#'`08G%2/_`28-\QO@`=?*#/85X(```08UU`G0C2&/V3(GW2,'F`^CP
MW___2(7`2(D%[F<@`'5`@\C_Z<T```!(8_;'!4]X(``!````2(T\]0````#H
MLN#__TB%P'3926/53(GV2(G'2,'B`^BKX/__2(D%K&<@`$B+!:5G(`!)8]5(
MQT30"`````!$B6PD!$B)Z(H0A-)T"H#Z/70%2/_`Z_!(8TPD!$B+%75G(`!(
M*>A(F$F-?`0"3(TLRNA*X/__2(7`28E%``^$:?___TAC5"0$2(L%26<@`$B+
M!-!(_\6*5?^$TH@0=`J`^CUT!4C_P.OJQ@`],=**#!.(3!`!2/_"A,EU\NGE
M_O__2(M<)`AD2#,<)2@```!T!>A*XO__2(/$$%M=05Q!74%>PT%6055!5%53
M2('LH````&1(BP0E*````$B)A"28````,<!(A?\/A.\```"`/P!(B?T/A.,`
M``#H@=[__TB%P$F)Q$R-;"0(#X3-````3(GGZ"C?__](A<`/A*P```!(C5@3
M2(TU514``$B)W^C\WO__A<!TV$B--4$5``!(B=_HZ=[__X7`=,5(@\[_,<!(
MB>](B?'RKDB)WTB)RDB)\?*N2/?22(G(2/?0C3P02&/_Z"C?__](C34$%0``
M28G&2(G'2(G92(GJ,<#H+N'__TR)]TR)[NCCX/___\!,B?=T%XM$)"`E`/``
M`#T`0```=0?H"O___^L%Z-#>__],B??HJ.#__^E#____3(GGZ!O?__](B>_H
M8^#__TB+A"28````9$@S!"4H````=`7H"^'__TB!Q*````!;74%<05U!7L-3
M2(G[2('LH````$B-="0(9$B+!"4H````2(F$))@````QP.BSWO__A<!U,8M4
M)""!X@#P``"!^@!```!T"('Z`*```'49O@(```!(B=_H>-W__X7`#Y3`#[;`
MZP(QP$B+C"28````9$@S#"4H````=`7HA.#__TB!Q*````!;PTB#[`B+/3%E
M(`#H'.#__TB+%95D(`!(B<=(C0WS4@``6$B--=P3``#IWM___TB#[`B+/01E
M(`#H[]___TB)Q^B\____BSWQ9"``Z-S?__](B<=,C056%@``2(T5S@\``%A(
MC36X$P``13')3(G!Z?C<__]!5%532('L$"```$B-;"0&9$B+!"4H````2(F$
M)`@@```QP.@`W?__3(T%DQ,``$B-%9`3``")P;X!$```,<!(B>_HH=S__X/X
M_W4',<GI@0```$ACT$B!^@`0``!V`@\+A<!XYTB-G"0'$```N@`0``!(B>](
MB=[H*][__X7`28G$>,B->`%(8__H&=W__TB%P$B)P72U2#G826/L<PE(C00H
M2#G#<K=(.=EV"4B-!"M(.<%RJ4&!_`$0``!_H$B)STB)ZDB)WN@+W___2(G!
MQ@0H`$B+M"0((```9$@S-"4H````2(G(=`7H&=___TB!Q!`@``!;74%<P^D`
M____05=!5D%505154TB)^TB-/;X2``!(B?5(@>RH$```9$B+!"4H````2(F$
M))@0```QP.@K^O__OB\```!(B=])B<7H$MW__TB%P'062(T]B1(``$B)WC'`
MZ*OZ___I)@$``#'`2(G?2(/)__*N2(TU=1(``$B)[TR-?"0(2/?12(VL))@`
M``!$C6'_Z!G>__]!_\1)B<9-A?9TL4&`/@!(C07D$0``3`]$\$V%[7033(GV
M3(GOZ'_;__^%P`^$L````#'`2(/)_TR)]_*N2/?1C4'_2&/(08!\#O\O=0S_
MR$ACR$'&!`X`Z^E$`>`]_P\```^/5/___TR-!>P1``!(C174$@``,<!)B=E,
MB?&^`!```$B)[^C.VO___\`]`!```'8"#PM,B?Y(B>_H6-W__X7`=3V+1"0@
M)0#P```]`(```'4MO@$```!(B>_HA]K__X7`=1Q(C3U_$0``2(GNZ*/Y__](
MB>_HG-O__TB)P^L62(TU<!$``#'_Z"G=__])B<;I#O___TB+E"28$```9$@S
M%"4H````2(G8=`7H9MW__TB!Q*@0``!;74%<05U!7D%?PTB-5P%(B?B*2O^$
MR70,@/DO2`]$PDC_PNOMPTB%_W1+1(H'2(G^183`=$`QP$B#R?_RKDCWT4B-
M5`[^2#G6<QF`.B]U#4C_RNOQ2/_*2#G6<P>`.B]U\^LC2#G6=1Y!@/@O2(T]
MS1```'4'2(T]8Q```.G=VO__@#HO=0A(_\I(.=9R\T@I\DB-0@)(/0`0``!W
M)TC_PDB!^@`0``!V`@\+2(T]W&$@`$B#[`CH4]O__TB-!<QA(`!:PS'`PU-(
MC37_3@``N2(```!(@^PP9$B+!"4H````2(E$)"@QP$B-?"0&2(U<)`;SI$B-
M/4<0``#H[_?__TB-/400```QP.CA]___2(T]/A```#'`Z-/W__](C3TY$```
M,<#HQ??__TB-/3(0```QP.BW]___2(T]-!```#'`Z*GW__](C3W;#P``,<#H
MF_?__TB-/200```QP.B-]___2(T](!```#'`Z'_W__](C3T<$```,<#H<??_
M_TB-/:P/```QP.AC]___2(T]"A```#'`Z!WW__](A<!T$4B-/>,/``!(B<8Q
MP.BM]___2(T]]P\``#'`Z/GV__](A<!T$4B-/?8/``!(B<8QP.B)]___2(T]
M\`\``#'`Z-7V__](A<!(B<9(C3TY#P``=1U(C3WC#P``,<#HN/;__TB%P'0.
M2(T]=`\``$B)QC'`ZR1(C7L12(TUSP\``+H*````Z/?8__^%P'402(US&TB-
M/4D/``#H(O?__TB--;4/``!(C3T:#P``,<#H#??__TB+1"0H9$@S!"4H````
M=`7H^=K__TB#Q#!;PX,]C%\@`/]U.$B-/00/``!(@^P(,<#H,?;__S'22(7`
M=`Z*`(3`#Y7"/#`/E<`AP@^VTHD56E\@`(L%5%\@`%K#BP5,7R``PTB#[`CH
MLMK__XG'Z`O9__\QTDB%P'0#2(L02(G06L-!5%5(B?U32(T]&0\``#'`Z-#U
M__](A<!(B>YT8H`X`$B)PW1:2(G'Z'_8__](A<!U7TB#SO](B>](B?'RKDB)
MWTB)RDB)\?*N2/?22(G(2/?02(T\`NC1U___2(TU^PX``$B-#0,.``!)B<1(
MB<=)B=A(B>HQP.C0V?__3(GF6UU!7$B-/9T.```QP.GZ]?__6UU!7,-!5T%6
M28G_055!5$B--51>(`!54[D,````2('L:($``&1(BP0E*````$B)A"18@0``
M,<!(C05N#@``2(U\)%A(QT0D.`````#SI4B)1"0H2(T%(0T``$B-/6,-``!(
MQT0D4`````!(B40D,$B-!3L.``!(B40D0$B-!30.``!(B40D2#'`Z,7T__](
MA<!T((`X`$B)PW082(G'Z,O^__](B=_H3]?__TB)P^G-"```,<!(C6PD0.B0
M_O__2(7`2(G#=3E(BWT`2(7_="DQP#';Z'KT__](A<!T$(`X`'0+2(G'Z`_7
M__](B<-(@\4(2(7;=-#K!TB-':4-```QP$B)WTB#R?_RKDR-):T-``!(]]%(
MC7P)_^A[UO__28G%2(G%@#L`=!D/MA-(B>],B>8QP$C_PTB#Q0+H>=C__^OB
M2(UL)%A(BUT`2(7;="Y(B=\QP.CX\___2(7`2(G#=".`.`!T'DB)Q^B/]___
MA<!T$DB)W^A^UO__2(G#3(UD)"CK,$B#Q0CKO$F++"1(A>UT)H!]``!T($B)
M[^A<]___A<!T"TB)[^A+UO__2(G#28/$"$B%VW312(/._S'`2(G?2(GQ\JY,
MB>](]]%(B<I(B?'RKDB)R$CWT(VL$`($``!(8^U(B>_HJ]7__TR-!<X,``!(
MC0W?"P``2(TUQ0P``$B)QTF)Q$V)Z4B)VC'`Z*/7__^^P`$``$R)Y^@VU___
M_\!U,N@=U___@S@1="CH$]?__TF+%T2+`$B--8X,``!(BSW_5R``3(GA,<#H
MA=;__^DD!P``3(VT)(@```!,B>=,B?;H;=7__X7`B40D"`^%Z@8``(N$)*``
M```E`/```#T`0```#X73!@``BYPDI````.ANU___.<,/A;\&``"+A"2@````
M)?\!```]P`$```^%J`8``$B)[^C7U/__2(T]U@L``$B)PS'`Z'_R__](A<!T
M&TB)Q^@9U?__28L_2(G&Z`;X__](A<!)B<5U`TV++S'`2(/)_TR)[_*N2/?1
M2(UI_X/]`WYC2&/%2(TU]0L``$F-?`7\Z`C4__^%P'5+@_T$=`Z#[01(8^U!
M@'PM_R]U.$F+;PA(A>UT+S'`2(/)_TB)[_*N2/?12(U!_TB#^`-V%TB-?`W[
M2(TUK`L``.B_T___A<!,#T3M,<#HC_O__X7`#X4J!0``,?9,B>_H@-3__X7`
M08G'#X05!0``2(VL)%@!``"Z`@```$C'QN[___^)Q^A:T___N@8```!(B>Y$
MB?_H6M7__X"\)%@!````=66`O"19`0``0W5;@+PD6@$``$%U48"\)%L!``!#
M=4>`O"1<`0``2'4]@+PD70$``$5U,[H"````2,?&QO___T2)_^CZTO__NBD`
M``!(B>Y$B?_H^M3__TR-#0<,``!)B>CI6P0``#'2,?9$B?_HS]+__[B)J\WO
M38UN.$C'A"2(`````2-%9TB)A"20````N/[<NIA(QX0DH````'94,A!(B80D
MF````+CPX=+#2,>$)+``````````2(F$)*@```!(QX0DN`````````#'A"0`
M`0```````+H`@```2(GN1(G_Z&G4__^%P$F)P8E$)`@/CG@!``!(BXPDL```
M`$ECP8T4P4@YT78(2/^$)+@```!(8[PD``$``$C!Z!U(`80DN````$B)E"2P
M````A?\/A)<```!!N$````!!*?A%.<%%#T[!3`'O2#GO26/(<PE(C00/2#G%
M<@](.>]V#$B-1`T`2#G'<P(/"TB!^0"```!,B4PD&$2)1"00=^M(B<I(B>Y(
MB4PD".ASU/__BX0D``$``$2+1"002(M,)`A,BTPD&$0!P(/X0(F$)``!```/
MA2'___]$B<A(C70-`$0IP(E$)`A(B70D$.LO2(GN@WPD"#]^3$PY[G<O3#GN
M2(U.0'(TND````!,B>](B4PD$.@*U/__@VPD"$!,B??HJM?__TB+="00Z\5)
MC49X2#G&<\CI4/___TDYS7/'Z4;___],.>Y(8U0D"'8.28U$%0!(.<8/@B[_
M__],.>YS#4B-!!9).<4/@AS___](@_I(#X<2____3(GOZ*+3__^+1"0(B80D
M``$``.EI_O__1(G_Z+K2__],BZPDL````$B+K"2X````3(GH2,'H`X/@/XU(
M`4B8QH0$P````("#^3A(8_E^+$V-?CBZ0````#'V*<I(8]),`?_HX]#__TR)
M]^CHUO__NC@````Q]DR)_^L1NC@```!)C7P^.#'V*<I(8]+HN=#__TB)Z$R)
M]T"(K"3[````2,'H&$2(K"3_````B(0D^````$B)Z$C!Z!"(A"3Y````2(GH
M,>U(P>@(B(0D^@```$R)Z$C!Z!B(A"3\````3(GH2,'H$(B$)/T```!,B>A,
MC:PD&P$``$C!Z`B(A"3^````Z%#6__](BX0DB````$R-A"0O`0``2(G"B(0D
M'@$``$C!ZAB(E"0;`0``2(G"2,'J$(B4)!P!``!(B<)(BX0DD````$C!Z@B(
ME"0=`0``2(G"B(0D(@$``$C!ZAB(E"0?`0``2(G"2,'J$(B4)"`!``!(B<)(
MBX0DF````$C!Z@B(E"0A`0``2(G"B(0D)@$``$C!ZAB(E"0C`0``2(G"2,'J
M$(B4)"0!``!(B<)(BX0DH````$C!Z@B(E"0E`0``2(G"B(0D*@$``$C!ZAB(
ME"0G`0``2(G"2,'J$(B4)"@!``!(B<)(BX0DJ````$C!Z@B(E"0I`0``2(G"
MB(0D+@$``$C!ZAB(E"0K`0``2(G"2,'J$(B4)"P!``!(B<)(P>H(B)0D+0$`
M`$(/ME0M`$B-?"T`2(TU808``#'`2/_%3(E$)`A,`<?H2M'__TB#_11,BT0D
M"'713(T-K`<``,:$)%<!````2(T-2P4``$B--7\&``!,B>)(B=\QP.@5T?__
MZ98```!(C37B!0``2(T]8P4``#'`2(TM;0<``.@S[?__Z$_.__],C0U<!P``
M2(T-`P4``$B--48&``!!B<!,B>)(B=\QP.C*T/__OL`!``!(B=_H7=#____`
M=3_H1-#__X,X$74U_T0D".@&SO__2(/L"$B-#;T$``!(C34.!@``54&)P$R)
MXD2+3"082(G?,<#H?M#__UA:Z[!,B>?H(M#__TB-/74$``!(B=XQP.B@[/__
M2(G?Z`WV___K'4F+%TB+/=U0(`!(C371!0``3(GA,<#H7,___S';2(G82(N<
M)%B!``!D2#,<)2@```!T!>A?T/__2('$:($``%M=05Q!74%>05_#055!5%53
M2(/L"(L]_50@`.CHS___BSWR5"``2(G#Z-K/__^*@+@```!(C3TB!```B(.Y
M````,<#H:>O__TB%P'0+@#@Q=0:`>`$`=`<QP.AB\___BSVS5"``Z)[/__](
MC361!0``N0L```"Z`0```$B)Q^@5SO__2(7`=36+/8I4(`#H=<___TB--6T%
M``"Y`P```+H!````2(G'Z.S-__](A<!(B<,/A<H```#I#`$``$B+0!`QVTR+
M8"B-:P$[+<AD(`!]((L]0%0@`.@KS___,<E(8]-,B>9(B<?HR\S__TB%P'43
MBP6@9"``_\@YPW6*NP$```#K5TR+*$&+10PE``0@`#T`!```=09)BT40ZQV+
M/?13(`#HW\[__[D"````,=),B>Y(B<?H#<___TB+#4YD(`!(8]5(B<9(BSS1
MZ#?,__^%P'6=B>OI:____SL=-F0@``^-(/___XL]JE,@`/_#Z)/.__],B>9(
MB<?H:,O__^O:2(M`$(L]C%,@`$B+*.ATSO__2(T5;@0``$B)QTB)[N@2S?__
M2(M#$$B+&/9##D!T%HL]7U,@`.A*SO__2(G>2(G'Z`_,__^+/4E3(`#H-,[_
M_TB--3,$``"Y`P```+H!````2(G'Z*O,__](A<!(B<4/A(<```!(C3TK`@``
M,<#HJNG__TB%P$B)PW0:2(M%$(L]_U(@`$B+*.CGS?__2(G:2(GNZT_H(N[_
M_TB%P$B)PXL]WE(@`$B+11!T($B+*.C`S?__2(G:2(G'2(GNZ&+,__](B=_H
M:LW__^L@2(L5*6,@`$B+&$B+*NB6S?__2(G>2(GJ2(G'Z#C,__^+/9)2(`#H
M?<W__TB--7X#``"Z`0```$B)Q^AYRO__BSUS4B``2(G#Z%O-__](C15Q`P``
M2(G>2(G'Z/G+__^+/5-2(`#H/LW__TB-/5$!``#&@+D`````,<#HTNC__TB%
MP$B)!;=B(`!U)$B+/9YB(`#H:_/__TB%P$B)!9]B(`!U#$B-/2$#``#H2<K_
M_TB+/8IB(`"^P`$``.B8S/__C5`!@_H!=B:#^!%T(8G!2(L%6F(@`$B+%6-B
M(`!(C3T(`P``2(LP,<#H"LK__UA;74%<05W#55-(B?M(@^P(Z+OO__](B<?H
MF.___TB)Q3'`Z._Q__^%P'0I2(7;="2`.P!T'TB--9<!``!(B>_HY<K__T@Y
MQ74+6DB)WUM=Z7CJ__]86UW#54B)Y5-(C1W53"``2(/L"$B#ZPA(BP-(@_C_
M=`3_T.OO6%M=PU#H/<___UC#`````"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!E>&4`+W!R;V,O
M)6DO)7,`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!015),-4Q)0@!015),
M3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.
M140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$
M14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,1%],24)205)9
M7U!!5$@`4UE35$5-`"]T;7``55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E
M<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`
M)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`"5S.B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`5$5-4$1)4@!435``05)'5@`8`'!E
M<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T-0!5;F%B;&4@=&\@8W)E
M871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I
M;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M
M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE
M.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF
M,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N
M960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN
M("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D
M<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]]
M(#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M
M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*
M>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&
M2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F
M<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U
M;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@
M(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]
M/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R
M.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E
M860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG
M(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE
M(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C
M:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F
M:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F
M=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?
M5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F
M+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO
M9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U:7)E
M7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@/2`D
M7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D969I
M;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A
M9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP<FEN
M="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1F
M:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E;B!M
M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL
M96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@
M(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O
M;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL97,[
M"B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE
M8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF
M:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME>7,@
M)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D:7(@
M*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER7$5<
M+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D,BD[
M"FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA
M*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*96QS
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@:F]I
M;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["F]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L;W-E
M($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M
M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]
M"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H(D9)
M3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN="@D
M8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(
M03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N
M(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@*"1C
M='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U
M="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S
M92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD
M9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H(EQN
M4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI
M=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P
M<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H
M:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@
M)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R
M(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C
M('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M
M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I
M<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64[
M"FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_
M.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#;VYF
M:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D
M14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N
M86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2![
M"F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR
M96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U=',H
M<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I
M*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PIC
M:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*
M?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@
M/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@
M6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN
M<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I
M.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H
M*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*
M?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@
M1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*
M<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C
M;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*
M<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z
M.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ
M6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E
M($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S
M971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR
M971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@
M0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM
M>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP9&ER
M(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[4$%2
M7T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;.5TI
M('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H+"`M
M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L("1B
M=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`](&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(
M03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E
M<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG
M97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N(&5Q
M("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M/F%D
M9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@
M*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I;FUO
M9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@
M/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I.PI]
M"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M92!O
M<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E("1F
M:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@
M)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N
M9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@
M:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%2
M7U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M
M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF
M("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P
M<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I
M(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN
M7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\[
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I
M;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I
M('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N
M)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E
M>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N
M(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%
M3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS
M:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L
M=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI
M.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%
M04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII
M9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R
M:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG
M.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I
M9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@
M<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A
M8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z
M.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64[
M"F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2
M(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@
M/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D
M.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("```````````'!E<FQX<VDN8P````$;`SO(````&````,R)
M___D````?(W__PP!``"4C?__\`0``-F0__\D`0``+*C__W`!``"UJ/__N`$`
M`.VH___0`0``6ZG___@!```?J___/`(``&&L__^``@``X:S__Z0"```.K?__
MO`(``%2M___4`@``3Z[__P@#``!4KO__'`,```BP__]H`P``([#__WP#``#%
ML/__E`,``&FR__^X`P``L;+__]`#``#0LO__Z`,``&:S__\@!```#[W__X`$
M``!:P/__O`0``!0``````````7I2``%X$`$;#`<(D`$``"0````<````X(C_
M_[`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1````&B,__\8````
M``````````!(````7````*V/__]3%P```$(.$(\"0@X8C@-&#B"-!$(.*(P%
M0PXPA@9!#CB#!T<.T`4#,1<..$$.,$$.*$(.($(.&$(.$$(."```1````*@`
M``"TIO__B0````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P=&#D`"
M:PXX1`XP00XH0@X@0@X80@X00@X(%````/````#UIO__.`````!$#B!S#@@`
M)`````@!```5I___;@````!!#A"&`D$.&(,#1PXP`F(.&$$.$$$."$`````P
M`0``6Z?__\0!````0@X0C@)"#AB-`T(.((P$00XHA@5$#C"#!D<.0`.I`0XP
M00XH00X@0@X80@X00@X(````0````'0!``#;J/__0@$```!"#A".`D(.&(T#
M0@X@C`1!#BB&!4$.,(,&1P[0`0,J`0XP00XH00X@0@X80@X00@X(```@````
MN`$``-FI__^``````$$.$(,"2@ZP`0)S#A!!#@@````4````W`$``#6J__\M
M`````$0.$%T."``4````]`$``$JJ__]&`````$0.$'`."``P````#`(``'BJ
M___[`````$(.$(P"00X8A@-!#B"#!$<.L$`"ZPX@00X800X00@X(````$```
M`$`"```_J___!0````````!(````5`(``#"K__^T`0```$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!U0.X"$#BP$..$$.,$$.*$(.($(.&$(.$$(.
M"```$````*`"``"8K/__&P`````````4````M`(``)^L__^B``````*1#A!-
M#@@@````S`(``"FM__^D`0```$$.$(,"4`Y``Y$!#A!!#@@````4````\`(`
M`*FN__](`````%0.$&P."``4````"`,``-FN__\?`````$0.$%H."``T````
M(`,``."N__^6`````$(.$(P"00X8A@-$#B"#!`)Y"@X800X00@X(3@M!#AA!
M#A!"#@@``%P```!8`P``/J___ZD)````0@X0CP)"#AB.`T4.((T$0@XHC`5(
M#C"&!D$..(,'3`Z@@P(#]`@.J(,"3PZP@P)6#JB#`D$.H(,"`F0..$$.,$$.
M*$(.($(.&$(.$$(."#@```"X`P``A[C__TL#````0@X0C0)"#AB,`T$.((8$
M00XH@P5$#C`#.@,.*$$.($$.&$(.$$(."````#````#T`P``EKO__U$`````
M00X0A@)!#AB#`T<.('H*#AA$#A!!#@A%"T$.&$$.$$$."``@````*`0``)R(
M___6`0```$$.$(,"1`XP`\T!#A!##@@`````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#__________P``````````____
M______\`````````````````````````````````````````````````````
M``````````````````````$``````````0`````````!`````````-P"````
M````#P````````!*!`````````P`````````$!@````````-`````````"1/
M````````]?[_;P`````@`@````````4`````````0`P````````&````````
M`!`#````````"@````````!H!`````````L`````````&``````````5````
M`````````````````P````````#(G2````````(`````````<`4````````4
M``````````<`````````%P````````"@$@````````<`````````J!``````
M```(`````````/@!````````"0`````````8`````````!@`````````````
M``````#[__]O``````$```@`````^?__;P`````'````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````*)P@````````````````````
M````````-A@```````!&&````````%88````````9A@```````!V&```````
M`(88````````EA@```````"F&````````+88````````QA@```````#6&```
M`````.88````````]A@````````&&0```````!89````````)AD````````V
M&0```````$89````````5AD```````!F&0```````'89````````AAD`````
M``"6&0```````*89````````MAD```````#&&0```````-89````````YAD`
M``````#V&0````````8:````````%AH````````F&@```````#8:````````
M1AH```````!6&@```````&8:````````=AH```````"&&@```````)8:````
M````IAH```````"V&@```````,8:````````UAH```````#F&@```````/8:
M````````!AL````````6&P```````"8;````````-AL```````!&&P``````
M`%8;````````9AL```````!V&P```````(8;````````EAL```````"F&P``
M`````+8;````````QAL`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````"@(```````````````````````````````````````$E``
M```````+4````````$Y1````````*%````````!640``````````````````
M_____P````#K40```````$=#0SH@*$%L<&EN92`V+C0N,"D@-BXT+C```"YS
M:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E
M;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`
M+FIC<@`N9&%T82YR96PN<F\`+F1Y;F%M:6,`+F1A=&$`+F)S<P`N8V]M;65N
M=```````````````````````````````````````````````````````````
M```````````````````````````````````+`````0````(```````````(`
M`````````@```````!D````````````````````!````````````````````
M$P```/;__V\"`````````"`"````````(`(```````#L``````````,`````
M````"````````````````````!T````+`````@`````````0`P```````!`#
M````````,`D````````$`````0````@`````````&``````````E`````P``
M``(`````````0`P```````!`#````````&@$```````````````````!````
M````````````````+0````0````"`````````*@0````````J!````````#X
M`0````````,`````````"``````````8`````````#<````$````0@``````
M``"@$@```````*`2````````<`4````````#````%`````@`````````&```
M``````!!`````0````8`````````$!@````````0&`````````T`````````
M```````````!````````````````````/`````$````&`````````"`8````
M````(!@```````"P`P``````````````````$``````````0`````````$<`
M```!````!@````````#0&P```````-`;````````&```````````````````
M``@`````````"`````````!0`````0````8`````````Z!L```````#H&P``
M`````#PS```````````````````!````````````````````5@````$````&
M`````````"1/````````)$\````````(`````````````````````0``````
M`````````````%P````!`````@`````````P3P```````#!/````````(C\`
M``````````````````@```````````````````!D`````0````(`````````
M5(X```````!4C@```````,P````````````````````$````````````````
M````<@````$````"`````````""/````````((\```````!,!```````````
M````````"````````````````````'P````!`````P````````#8FR``````
M`-B;````````$`````````````````````@```````````````````"#````
M`0````,`````````Z)L@``````#HFP```````!`````````````````````(
M````````````````````B@````$````#`````````/B;(```````^)L`````
M```(````````````````````"````````````````````(\````!`````P``
M````````G"````````"<````````(P```````````````````!``````````
M``````````"<````!@````,`````````*)P@```````HG````````*`!````
M````!``````````(`````````!``````````2P````$````#`````````,B=
M(```````R)T````````P`@``````````````````"``````````(````````
M`*4````!`````P``````````H"````````"@````````8```````````````
M`````"````````````````````"K````"`````,`````````8*`@``````!@
MH````````*@0```````````````````@````````````````````L`````$`
M```P````````````````````8*`````````:`````````````````````0``
M```````!``````````$````#`````````````````````````'J@````````
@N0````````````````````$`````````````````````
